@@ -83,9 +83,9 @@ selectDVforEV <- function(dvdata, alpha = 0.01, retest = FALSE, test = "Chisq",
                           quiet = FALSE) {
 
   names(dvdata) <- make.names(names(dvdata), allow_ = FALSE)
-  stopifnot(class(dvdata)=="list",
+  stopifnot(inherits(dvdata, "list"),
             length(dvdata)>1,
-            all(lapply(dvdata[-1], class)=="data.frame"))
+            all(sapply(X=dvdata[-1], FUN=inherits, what="data.frame")))
   rv <- dvdata[[1]]
   .binaryrvcheck(rv)
   evdv <- dvdata[-1]
